@@ -1,6 +1,6 @@
-"""A Jupyter notebook server extension for managing Dask clusters."""
+"""A Jupyter server extension for managing Dask clusters."""
 
-from notebook.utils import url_path_join
+from jupyter_server.utils import url_path_join
 
 from . import config
 from .clusterhandler import DaskClusterHandler
@@ -13,6 +13,15 @@ __version__ = get_versions()["version"]
 del get_versions
 
 
+def _jupyter_labextension_paths():
+    return [
+        {
+            "src": "labextension",
+            "dest": "dask-labextension",
+        }
+    ]
+
+
 def _jupyter_server_extension_paths():
     return [{"module": "dask_labextension"}]
 
@@ -32,9 +41,7 @@ def load_jupyter_server_extension(nb_server_app):
     get_dashboard_path = url_path_join(
         base_url, f"dask/dashboard/{cluster_id_regex}(?P<proxied_path>.+)"
     )
-    check_dashboard_path = url_path_join(
-        base_url, "dask/dashboard-check/(?P<url>.+)"
-    )
+    check_dashboard_path = url_path_join(base_url, "dask/dashboard-check/(?P<url>.+)")
     handlers = [
         (get_cluster_path, DaskClusterHandler),
         (list_clusters_path, DaskClusterHandler),
