@@ -8,8 +8,8 @@ from urllib import parse
 
 from tornado import httpclient, web
 
-from notebook.base.handlers import APIHandler
-from notebook.utils import url_path_join
+from jupyter_server.base.handlers import APIHandler
+from jupyter_server.utils import url_path_join
 from jupyter_server_proxy.handlers import ProxyHandler
 
 from .manager import manager
@@ -29,38 +29,73 @@ class DaskDashboardCheckHandler(APIHandler):
         try:
             client = httpclient.AsyncHTTPClient()
 
-            # Check the user-provided url, following any redirects.
+            # First check for the individual-plots endpoint at user-provided url.
+            # We don't check for the root URL because that can trigger a lot of
+            # object creation in the bokeh document.
             url = _normalize_dashboard_link(parse.unquote(url), self.request)
-            response = await client.fetch(url)
-            effective_url = response.effective_url if response.effective_url != url else None
-
-            # Fetch the individual plots
-            individual_plots_response = await client.fetch(
-                url_path_join(
-                    _normalize_dashboard_link(effective_url or url, self.request),
-                    "individual-plots.json"
-                    )
+            effective_url = None
+            individual_plots_url = url_path_join(
+                url,
+                "individual-plots.json",
             )
+            try:
+                self.log.debug(
+                    f"Checking for individual plots at {individual_plots_url}"
+                )
+                individual_plots_response = await client.fetch(individual_plots_url)
+                self.log.debug(f"{individual_plots_response.code}")
+            except httpclient.HTTPError as err:
+                # If we didn't get individual plots, we may have to follow a redirect first.
+                self.log.debug(f"Checking for redirect at {url}")
+                response = await client.fetch(url)
+                effective_url = (
+                    _normalize_dashboard_link(response.effective_url, self.request)
+                    if response.effective_url != url
+                    else None
+                )
+                # If there was no redirect, raise.
+                if not effective_url:
+                    raise err
+
+                individual_plots_url = url_path_join(
+                    effective_url,
+                    "individual-plots.json",
+                )
+                self.log.debug(f"Found redirect at {effective_url}")
+                self.log.debug(
+                    f"Checking for individual plots at {individual_plots_url}"
+                )
+                individual_plots_response = await client.fetch(individual_plots_url)
+
             # If we didn't get individual plots, it may not be a dask dashboard
             if individual_plots_response.code != 200:
                 raise ValueError("Does not seem to host a dask dashboard")
+
             individual_plots = json.loads(individual_plots_response.body)
 
             self.set_status(200)
-            self.finish(json.dumps({
-                "url": url,
-                "isActive": response.code == 200,
-                "effectiveUrl": effective_url,
-                "plots": individual_plots,
-            }))
-        except:
-            self.log.warn(f"{url} does not seem to host a dask dashboard")
+            self.finish(
+                json.dumps(
+                    {
+                        "url": url,
+                        "isActive": True,
+                        "effectiveUrl": effective_url,
+                        "plots": individual_plots,
+                    }
+                )
+            )
+        except Exception:
+            self.log.debug(f"{url} does not seem to host a dask dashboard")
             self.set_status(200)
-            self.finish(json.dumps({
-                "url": url,
-                "isActive": False,
-                "plots": {},
-            }))
+            self.finish(
+                json.dumps(
+                    {
+                        "url": url,
+                        "isActive": False,
+                        "plots": {},
+                    }
+                )
+            )
 
 
 class DaskDashboardHandler(ProxyHandler):
@@ -127,7 +162,7 @@ class DaskDashboardHandler(ProxyHandler):
         parsed = parse.urlparse(dashboard_link)
         port = parsed.port
         if not port:
-            port = 443 if parsed.scheme == 'https' else 80
+            port = 443 if parsed.scheme == "https" else 80
         if not parsed.hostname:
             raise web.HTTPError(500, "Dask dashboard URI malformed")
         return parsed.hostname, port
@@ -143,5 +178,5 @@ def _normalize_dashboard_link(link, request):
         link = url_path_join(f"{request.protocol}://{request.host}", link)
     if link.endswith("/status"):
         # If the default "status" dashboard is given, strip it.
-        link = link[:-len("/status")]
+        link = link[: -len("/status")]
     return link
